#!/bin/sh

#------------------------------------------------------------------------------
# This is a simple example job script with SGE scheduler (e.g., argon.uiowa)
#------------------------------------------------------------------------------
#$ -N JobSGE
#$ -q ARROMA
#$ -l h_rt=24:00:00
#$ -l h_vmem=4G
#$ -cwd

#------------------------------------------------------------------------------
# This is smiple example jobs script with SLURM (e.g., maya.umbc, crane.unl)
#------------------------------------------------------------------------------
#SBATCH --job-name=JobSLURM
##SBATCH --time=00:30:00
#SBATCH --partition=batch
###SBATCH --mem-per=4096
#SBATCH --error=job.%J.e
#SBATCH --output=job.%J.o

#------------------------------------------------------------------------------
# This is a simple example job script with PBS scheduler (e.g., nasa Pleiades)
#------------------------------------------------------------------------------
##: 
#PBS -N JobPBS
#PBS -l select=1:ncpus=1:model=san
#PBS -q normal

# unlimited memory and enable large stack size
ulimit -s unlimited
export KMP_STACKSIZE=9209715200

#------------------------------------------------------------------------------
# Load necessary modules (intel fortran and netcdf)
#------------------------------------------------------------------------------
# For argon@uiowa only:
#module load netcdf-fortran/4.4.4_parallel_studio-2017.1  # argon@uiowa

# For taki@umbc only:
module load intel/2018b
module load netCDF-Fortran/4.4.4-intel-2018b

# For Pleiades@NASA-NAS only:
#module load comp-intel/2015.3.187
#module load hdf4/4.2.12
#module load hdf5/1.8.18_serial
#module load netcdf/4.4.1.1_serial

#------------------------------------------------------------------------------
# Define your run & out directory
#------------------------------------------------------------------------------
rundir=./
outdir=./outputs

#------------------------------------------------------------------------------
# Now go to the run directory and start to run
#------------------------------------------------------------------------------
cd $rundir
if [ ! -d "$outdir" ]; then
   mkdir $outdir
fi

#------------------------------------------------------------------------------
# lut settings
#------------------------------------------------------------------------------
sza=24.0
aerosol=1
for aod in 0.0 0.2 0.5 1.0 2.0 3.0 5.0; do
for raz in 0 12 24 36 48 60 72 84 96 108 120 132 144 156 168 180; do
for lev in TOA BOA; do

  rec_raz="$((180-$raz))"
  diag=${lev}_SZA${sza}_RAZ${rec_raz}_AOD${aod}_MODE${aerosol}
  echo $diag

  if [ "$aod" == 0.0 ]; then 
    do_aerosol=F
  else     
    do_aerosol=T
  fi

  # copy the mast namelist file, and replace strings
  cp -v NAMELIST.MASTER.${lev}  namelist.ini
  sed "s/SZA_XX/${sza}/g" namelist.ini > namelist.ini.temp
  mv namelist.ini.temp namelist.ini
  sed "s/RAZ_XX/${raz}/g" namelist.ini > namelist.ini.temp
  mv namelist.ini.temp namelist.ini
  sed "s/DO_AEROSOL_XX/${do_aerosol}/g" namelist.ini > namelist.ini.temp
  mv namelist.ini.temp namelist.ini
  sed "s/AOD_XX/${aod}/g" namelist.ini > namelist.ini.temp
  mv namelist.ini.temp namelist.ini
  sed "s/DIAG_XX/${diag}/g" namelist.ini > namelist.ini.temp
  mv namelist.ini.temp namelist.ini

  time ./unlvrtm.exe
  cp namelist.ini $outdir/namelist.ini.${diag}

done
done
done

#time ./unlvrtm.exe

# finially delete the executable file
#rm ./unlvrtm.exe

